Function borrowed_decimal75

pub fn borrowed_decimal75<S: Scalar>(
    name: impl Into<Ident>,
    precision: u8,
    scale: i8,
    data: impl IntoIterator<Item = impl Into<S>>,
    alloc: &Bump,
) -> (Ident, Column<'_, S>)
Creates a (Ident, Column) pair for a decimal75 column. This is primarily intended for use in conjunction with table.

Example

use bumpalo::Bump;
use proof_of_sql::base::{database::table_utility::*};
let alloc = Bump::new();
let result = table::<MyScalar>([
    borrowed_decimal75("a", 12, 1, [1, 2, 3], &alloc),
]);

Panics

  • Panics if creating the Precision from the specified precision value fails.