pub struct ProvableQueryResult { /* private fields */ }Expand description
An intermediate form of a query result that can be transformed to either the finalized query result form or a query error
Implementations
Sourceimpl ProvableQueryResult
impl ProvableQueryResult
Sourcepub fn num_columns(&self) -> usize
pub fn num_columns(&self) -> usize
The number of columns in the result
Sourcepub fn table_length(&self) -> usize
pub fn table_length(&self) -> usize
The number of rows in the result
Sourcepub fn new<'a, S: Scalar>(
table_length: u64,
columns: &'a [Column<'a, S>],
) -> Self
pub fn new<'a, S: Scalar>( table_length: u64, columns: &'a [Column<'a, S>], ) -> Self
Form intermediate query result from index rows and result columns
Panics
Will panic if table_length is somehow larger than the length of some column
which should never happen.
Sourcepub fn evaluate<S: Scalar>(
&self,
evaluation_point: &[S],
output_length: usize,
column_result_fields: &[ColumnField],
) -> Result<Vec<S>, QueryError>
pub fn evaluate<S: Scalar>( &self, evaluation_point: &[S], output_length: usize, column_result_fields: &[ColumnField], ) -> Result<Vec<S>, QueryError>
Given an evaluation vector, compute the evaluation of the intermediate result columns as spare multilinear extensions
Panics
This function will panic if the length of evaluation_point does not match self.num_columns.
It will also panic if the data array is not properly formatted for the expected column types.
Sourcepub fn to_owned_table<S: Scalar>(
&self,
column_result_fields: &[ColumnField],
) -> Result<OwnedTable<S>, QueryError>
pub fn to_owned_table<S: Scalar>( &self, column_result_fields: &[ColumnField], ) -> Result<OwnedTable<S>, QueryError>
Convert the intermediate query result into a final query result
The result is essentially an OwnedTable type.