#[non_exhaustive]pub enum AggregateExecError {
UnsupportedGroupByExpressionCount {
count: usize,
},
UnsupportedGroupByExpressionType {
data_type: ColumnType,
},
}Expand description
Errors returned when an aggregate proof plan cannot be constructed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedGroupByExpressionCount
Grouping and deduplication support at most one expression.
UnsupportedGroupByExpressionType
The grouping expression has a datatype for which uniqueness cannot be proven.
Fields

data_type: ColumnTypeUnsupported grouping datatype.