pub trait TestAccessor<C: Commitment>:
Clone
+ Default
+ MetadataAccessor
+ SchemaAccessor
+ CommitmentAccessor<C>
+ DataAccessor<C::Scalar> {
type Table;
// Required methods
fn new_empty() -> Self;
fn add_table(
&mut self,
table_ref: TableRef,
data: Self::Table,
table_offset: usize,
);
fn get_column_names(&self, table_ref: &TableRef) -> Vec<&str>;
fn update_offset(&mut self, table_ref: &TableRef, new_offset: usize);
}Expand description
A trait that defines the interface for a combined metadata, schema, commitment, and data accessor for unit testing or example purposes.
Required Associated Types
Required Methods
Sourcefn add_table(
&mut self,
table_ref: TableRef,
data: Self::Table,
table_offset: usize,
)
fn add_table( &mut self, table_ref: TableRef, data: Self::Table, table_offset: usize, )
Add a new table to the current test accessor
Sourcefn get_column_names(&self, table_ref: &TableRef) -> Vec<&str>
fn get_column_names(&self, table_ref: &TableRef) -> Vec<&str>
Get the column names for a given table
Sourcefn update_offset(&mut self, table_ref: &TableRef, new_offset: usize)
fn update_offset(&mut self, table_ref: &TableRef, new_offset: usize)
Update the table offset alongside its column commitments
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".